@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: network-uri
 version: 2.6.1.0
-id: network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-key: netwo_DarCcUHK1BCJHlIYOjXe67
+id: network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
+key: netwo_8hCRgBDYvZA6nRJCSPBXws
 license: BSD3
 maintainer: ezra@ezrakilty.net
 homepage: https://github.com/haskell/network-uri
@@ -37,11 +37,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.1.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.1.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/network-uri-2.6.1.0
-hs-libraries: HSnetwork-uri-2.6.1.0-DarCcUHK1BCJHlIYOjXe67
+hs-libraries: HSnetwork-uri-2.6.1.0-8hCRgBDYvZA6nRJCSPBXws
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
 haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
 haddock-html: /usr/share/doc/haskell-network-uri/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
